\name{sequentialRM}
\alias{sequentialRM}

\title{ The sequential approach }
\description{
Use the sequential approach introduced in the reference to speed up the running of integer linear programming (ILP).
}

\usage{
sequentialRM(I, y, nupstart, by = 1, alpha, gamma, p)
}

\arguments{
  \item{I}{The incidence 0-1 matrix with unique row and column names, where rows are parts (genes) and columns are wholes (gene-sets).}
  \item{y}{Gene-level 0-1 data with the same names as the row names of I.}
  \item{nupstart}{The starting upper bound used in the sequential approach.}
  \item{by}{The increment of the upper bound used in the sequential approach, default value 1.}
 \item{alpha}{The false positive rate in role model, numeric value between 0 and 1. See reference.}
  \item{gamma}{The true positive rate in role model, numeric value between 0 and 1. See reference.}
  \item{p}{The prior active probability of wholes in role model, numeric value between 0 and 1. See reference.}
}

\details{
Generally, alpha and gamma can be estimated from the gene-level data by users themselves (see reference for examples), and alpha is less than gamma. p can be estimated via R package \code{MGSA} with alpha and gamma fixed.

We first perform the ILP on an initial incidence matrix (the smaller matrix) with lower bound equal lower bound of I and upper bound nupstart; then do another ILP, making use of the results obtained from the last ILP, on the bigger incidence matrix with upper bound equal nupstart + by. This process is repeated until the original incidence matrix I is reached. The suggested value for nupstart is 10. \code{sequentialRM} is our main function to perform the ILP calculation. \code{ILP}, \code{shrinkRM} and \code{optimalRM} are all invoked in this function.
}

\value{Return a list consisting of onwholes: the active wholes, i.e., the MFA-ILP estimate, and sol: has the same structure with the output of \code{ILP}.}

\references{Zhishi W., Qiuling H., Bret L. and Michael N.: A multi-functional analyzer uses parameter constaints to improve the efficiency of model-based gene-set analysis (2013). }
%\seealso{}
\author{ Zhishi Wang, Michael Newton and Subhrangshu Nandi.}

\examples{
data(Type2D)
## set the system parameters
alpha <- 0.00019
gamma <- 0.02279
p <- 0.00331
## use the sequential approach to get the MAP estimate on the Type 2 diabetes example
res <- sequentialRM(I, y, nupstart = 10, by =1, alpha, gamma, p)
}



